- Visão geral
- Requisitos
- Instalação
- Q&A: Deployment templates
- Configuração das máquinas
- Configurando o objectstore externo
- Configurando um registro externo do Docker
- Configuração do balanceador de carga
- Configuração do DNS
- Como configurar o Microsoft SQL Server
- Configuração dos certificados
- Instalação online de produção pronta para alta disponibilidade de vários nós
- Instalação offline de produção pronta para alta disponibilidade de vários nós
- Disaster Recovery - Instalando o cluster secundário
- Baixando os pacotes de instalação
- Parâmetros do install-uipath.sh
- Como habilitar o High Availability Add-on do Redis para o cluster
- Arquivo de configuração do Document Understanding
- Adicionando um nó de agente dedicado com suporte a GPU
- Adição de um nó de agente dedicado ao Task Mining
- Conexão do aplicativo Task Mining
- Adicionando um nó de agente dedicado para robôs do Automation Suite
- Pós-instalação
- Administração de cluster
- Monitoramento e alertas
- Migração e atualização
- Opções de migração
- Etapa 1: mover os dados da organização do Identity, de independente para o Automation Suite
- Etapa 2: restauração do banco de dados de produtos independente
- Etapa 3: backup do banco de dados da plataforma no Automation Suite
- Etapa 4: mesclando organizações no Automation Suite
- Etapa 5: atualização das strings de conexão do produto migradas
- Etapa 6: migração do Insights independente
- Etapa 7: exclusão do tenant padrão
- Executando uma migração de único tenant
- Configuração específica do produto
- Melhores práticas e manutenção
- Solução de problemas
- Como solucionar problemas dos serviços durante a instalação
- Como desinstalar o cluster
- Como limpar os artefatos offline para melhorar o espaço em disco
- Como limpar os dados do Redis
- Como habilitar o registro em log do Istio
- Como limpar logs manualmente
- Como limpar logs antigos armazenados no bucket do sf-logs
- Como desabilitar os logs de streaming para o AI Center
- Como depurar instalações do Automation Suite com falha
- Como excluir imagens do instalador antigo após a atualização
- Como limpar automaticamente instantâneos do Longhorn
- Como desabilitar o descarregamento de soma de verificação do TX
- Como definir manualmente o nível de log do ArgoCD como Info
- Como gerar o pull_secret_value codificado para registros externos
- Como lidar com cifras fracas no TLS 1.2
- Como trabalhar com certificados
- Como coletar dados de uso de DU com objectstore (Ceph) no cluster
- Como instalar o RKE2 SELinux em ambientes air-gapped
- Como limpar backups diferenciados antigos em um servidor NFS
- Não é possível executar uma instalação offline no SO RHEL 8.4
- Erro ao baixar o pacote
- A instalação offline falha devido a um binário ausente
- Problema de certificado na instalação offline
- A primeira instalação falha durante a configuração do Longhorn
- Erro de validação da string de conexão ao SQL
- Verificação de pré-requisito para o módulo iscsid do selinux falha
- Azure disk not marked as SSD
- Falha após a atualização do certificado
- Antivírus causa problemas de instalação
- Automation Suite not working after OS upgrade
- O Automation Suite requer que backlog_wait_time seja definido como 0
- Nó da GPU afetado por indisponibilidade de recurso
- Não é possível montar o volume devido a não estar pronto para cargas de trabalho
- Falha na coleta de logs do pacote de suporte
- A atualização de nó único falha no estágio de malha
- Cluster unhealthy after automated upgrade from 2021.10
- Upgrade fails due to unhealthy Ceph
- RKE2 não é iniciado devido a um problema de espaço
- A validação de SQL falha durante a atualização
- pod snapshot-controller-crds no estado CrashLoopBackOff após a atualização
- Falha ao carregar ou baixar dados no objectstore
- PVC resize does not heal Ceph
- Falha no redimensionamento do PVC
- Falha no redimensionamento do PVC do Objectstore
- Pod do Rook Ceph ou Looker travado no estado Init
- Erro de anexo de volume StatefulSet
- Falha ao criar volumes persistentes
- Patch de reclamação de armazenamento
- Falha de backup devido ao erro TooManySnapshots
- Todas as réplicas do Longhorn estão com falha
- Configurando um intervalo de tempo limite para os portais de gerenciamento
- Atualizar as conexões de diretório subjacentes
- Autenticação não funciona após migração
- kinit: não é possível encontrar o KDC para o realm <AD Domain> ao obter credenciais iniciais
- kinit: o Keytab não contém chaves adequadas para *** ao obter credenciais iniciais
- Falha na operação GSSAPI devido a código de status inválido
- Alarme recebido para trabalho com falha do Kerberos-tgt-update
- Provedor de SSPI: servidor não encontrado no banco de dados Kerberos
- Falha de login para usuário do AD devido a conta desabilitada
- ArgoCD login failed
- Falha ao obter a imagem do sandbox
- Os pods não são exibidos na UI do ArgoCD
- Falha de teste do Redis
- O servidor RKE2 falha ao iniciar
- Segredo não encontrado no namespace da UiPath
- O ArgoCD entra em estado Em andamento após a primeira instalação
- Problemas de acesso à conta somente leitura do ArgoCD
- Pods de MongoDB em CrashLoopBackOff ou provisionamento de PVC pendente após exclusão
- Unhealthy services after cluster restore or rollback
- Pods presos em Init:0/X
- Prometheus no estado CrashloopBackoff com erro de falta de memória (OOM)
- Métricas Ceph-rook ausentes nos painéis de monitoramento
- Os pods não podem se comunicar com o FQDN em um ambiente de proxy
- Falha ao configurar alertas por e-mail após a atualização
- Nenhum problema upstream íntegro
- O Document Understanding não está no menu de navegação esquerdo do Automation Suite
- Status de Falha ao criar uma sessão de rotulagem de dados
- Status de Falha ao tentar implantar uma habilidade de ML
- Trabalho de migração falha no ArgoCD
- Reconhecimento de escrita com o Extrator de formulários inteligente não está funcionando
- Falha na implantação de habilidade de ML devido à expiração do token
- Execução de alta disponibilidade com o Process Mining
- Falha na ingestão do Process Mining ao fazer logon usando o Kerberos
- Não é possível conectar-se ao banco de dados AutomationSuite_ProcessMining_Warehouse usando uma string de conexão em formato pyodbc.
- A instalação do Airflow falha com sqlalchemy.exc.ArgumentError: não foi possível analisar o URL rfc1738 da string ''
- Como adicionar uma regra de tabela de IP para usar a porta 1433 do SQL Server
- Usando a ferramenta de diagnóstico do Automation Suite
- Usando o pacote de suporte do Automation Suite
- Exploração de logs
Parâmetros do install-uipath.sh
O instalador manual install-uipath.sh permite personalizar a experiência de instalação sem executar o instalador interativo (installUiPathAS.sh).
Embora o instalador manual seja adequado para o cenário avançado, os modelos de implantação e o instalador interativo ainda são as opções recomendadas.
The install-uipath.sh installer is available in as-installer.zip. For download instructions, see Downloading installation packages.
Parâmetros obrigatórios
--input -i <string>
Especifique o arquivo de entrada .json.
input.json refers to the cluster_config.json that defines the parameters, settings, and preferences applied to the UiPath® services deployed via Automation Suite. You need to update this file to change the defaults and use any advanced configuration for your cluster. For details, refer to Manual: Advanced installation experience.
--output -o <string>
Especifique o arquivo de saída .json.
output.json refere-se ao arquivo de saída do instalador manual.
Parâmetros opcionais
--install-kubernetes -k
Instale o cluster do Kubernetes.
--join-node -j <server|agent>
Usado apenas com -k. Determina o tipo de nó a ser associado a um cluster existente. Valores permitidos: <server|agent>.
--install-fabric -f
Instale os componentes do Fabric.
--install-services -s
Instale os serviços da UiPath.
--install-all -a
Execute todos os instaladores em ordem. Se nenhuma instalação for explicitamente selecionada, –install-all estará implícito.
--install-type <online|offline>
Especifique o tipo de instalação. O padrão é online. Você não pode defini-lo-lo como online junto com –offline-bundle.
--offline-bundle <string>
Especifique o caminho para o pacote offline. Indica que o método de instalação é tarball.
--offline-tmp-folder <string>
Sinalização opcional que pode ser usada com --offline-bundle ou --optional-offline-bundle. Especifique o diretório pai para a pasta de instalação offline temporária. O padrão é /tmp.
--optional-offline-bundle <string>
Especifique o caminho para o pacote offline opcional.
--pre-reqs -p
Verifique os pré-requisitos. Ao usar este sinalizador, nenhum outro sinalizador pode ser passado.
--install-offline-prereqs
Utilizado com o método de instalação tarball, realiza a instalação de todos os pré-requisitos.
--skip-packages-install
Ignora a instalação de pré-requisitos durante o método de instalação online. Por padrão, os pré-requisitos são instalados.
--upgrade -u
Faça o upgrade de um cluster existente do Automation Suite.
--kubeconfig <string>
Especifique o caminho para o arquivo kubeconfig. Quando este sinalizador está ausente, o padrão é /etc/rancher/rke2/rke2.yaml.
--backup -b
Faça backup do cluster.
--restore -r
Restaure o cluster.
--restore-volume
Restaura o volume.
--disable-backup
Desabilite o backup.
-d
Execute no modo de depuração.
-h
Exibe a ajuda.
--accept-license-agreement
Sinalizador obrigatório para aceitar o contrato de licença.
-c
Instale o Cilium CNI (Container Network Interface) para substituir o Canal padrão. Usado apenas durante a atualização. Você não pode usá-lo com nenhum sinalizador de instalação.
--skip-pre-reqs
Ignore as verificações de pré-requisito durante a instalação. Observe que você não pode ignorar a validação do pacote RPM.
--one-time-manual-backup
Acione o backup manual e desabilite-o após a conclusão.
-m|--machines <comma separated machine's IP>
Especifique as máquinas de destino para instalação. Forneça endereços IP separados por vírgula ou nomes de host de todas as máquinas.
--compare-config
Compare o arquivo de configuração atual com o estado do cluster. Ele compara o arquivo input.json com a configuração de cluster atual.
--skip-compare-config
Ignore a comparação da configuração atual com o estado do cluster.
Exemplos
-
Instale os componentes do cluster do Kubernetes na VM em que ele é executado, usando o método de instalação online.
install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement -
Instale os componentes do Kubernetes na VM em que ele é executado e associe-o ao cluster existente como um servidor, usando o método de instalação online.
install-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreement -
Realize a instalação completa na VM atual, usando o método de instalação online. Inclui os componentes do cluster do Kubernetes, o Fabric e os serviços Uipath.
install-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreement -
Realize a instalação completa na VM atual, usando o método de instalação online. Desta vez, ignore a instalação de pré-requisitos.
install-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreement -
Realize a instalação do cluster do Kubernetes, usando o método de instalação tarball. Além disso, associe o nó ao cluster existente e instale todos os pré-requisitos offline.
install-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/as-infra.tar.gz" --accept-license-agreement --install-offline-prereqsinstall-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/as-infra.tar.gz" --accept-license-agreement --install-offline-prereqs -
Instale os componentes do Fabric e de serviços usando o método de instalação offline, sem uma pasta temporária fornecida.
install-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/as-infra.tar.gz" --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/as-infra.tar.gz" --accept-license-agreement -
Execute o instalador para uma instalação offline, mas sem carregar os artefatos.
install-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreement -
Execute o instalador ignorando a verificação de pré-requisitos
install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqsinstall-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqs
- Parâmetros obrigatórios
--input -i <string>--output -o <string>- Parâmetros opcionais
--install-kubernetes -k--join-node -j <server|agent>--install-fabric -f--install-services -s--install-all -a--install-type <online|offline>--offline-bundle <string>--offline-tmp-folder <string>--optional-offline-bundle <string>--pre-reqs -p--install-offline-prereqs--skip-packages-install--upgrade -u--kubeconfig <string>--backup -b--restore -r--restore-volume--disable-backup-d-h--accept-license-agreement-c--skip-pre-reqs--one-time-manual-backup-m|--machines <comma separated machine's IP>--compare-config--skip-compare-config- Exemplos